==> haskell-incremental-parser-0.5.0.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 incremental-parser
version:              0.5.0.2
visibility:           public
id:                   incremental-parser-0.5.0.2-31GPSdN572O49uGe0kBFDa
key:                  incremental-parser-0.5.0.2-31GPSdN572O49uGe0kBFDa
license:              GPL-3.0-only
copyright:            (c) 2011-2018 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://github.com/blamario/incremental-parser
synopsis:
    Generic parser library capable of providing partial results from partial input.

description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.

category:             Parsing
abi:                  ecb7ce414a82eb13079c458db11480f1
exposed:              True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric

import-dirs:          /usr/lib/ghc-8.10.4/site-local/incremental-parser-0.5.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/incremental-parser-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/incremental-parser-0.5.0.2

hs-libraries:         HSincremental-parser-0.5.0.2-31GPSdN572O49uGe0kBFDa
depends:
    base-4.14.1.0 input-parsers-0.1.0.1-7MSrcE88JVsIQp8nBtVbhg
    monoid-subclasses-1.1-BtwdZVkVFk74zoD1bPNmCI
    parsers-0.12.10-Hie1ki7uw2N1JEethNT4Ik
    rank2classes-1.4.1-2iRnSKiHaMf8RRKR8tcT2W transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock

haddock-html:         /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-incremental-parser-0.5.0.2-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-incremental-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 incremental-parser
version:              0.5.0.2
visibility:           public
id:                   incremental-parser-0.5.0.2-YNGm73SFQOBeYoaD2oZcd
key:                  incremental-parser-0.5.0.2-YNGm73SFQOBeYoaD2oZcd
license:              GPL-3.0-only
copyright:            (c) 2011-2018 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://github.com/blamario/incremental-parser
synopsis:
    Generic parser library capable of providing partial results from partial input.

description:
    This package defines yet another parser combinator library. This one is implemented using the concept of Brzozowski
    derivatives, tweaked and optimized to work with any monoidal input type. Lists, ByteString, and Text are supported out
    of the box, as well as any other data type for which the monoid-subclasses package defines instances. If the parser
    result is also a monoid, its chunks can be extracted incrementally, before the complete input is parsed.

category:             Parsing
abi:                  95b29e5c8f624eeb012d5196a9d4d9f8
exposed:              True
exposed-modules:
    Control.Applicative.Monoid Text.ParserCombinators.Incremental
    Text.ParserCombinators.Incremental.LeftBiasedLocal
    Text.ParserCombinators.Incremental.Symmetric

import-dirs:          /usr/lib/ghc-8.10.4/site-local/incremental-parser-0.5.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/incremental-parser-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/incremental-parser-0.5.0.2

hs-libraries:         HSincremental-parser-0.5.0.2-YNGm73SFQOBeYoaD2oZcd
depends:
    base-4.14.1.0 input-parsers-0.1.0.1-B8lI7wF9kxeFoMBJAwIPVz
    monoid-subclasses-1.1-7krNJY7GloP9SYNkGpf30o
    parsers-0.12.10-CwOfIgigS5h1OinokBgFQl
    rank2classes-1.4.1-E5noDhz1KwvI69NTaKjqZQ transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-incremental-parser/html/incremental-parser.haddock

haddock-html:         /usr/share/doc/haskell-incremental-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
